@@ -625,7 +625,7 @@ impl SourceMap {
             if options.with_source_contents &&
                !builder.has_source_contents(raw.src_id) {
                 builder.set_source_contents(
-                    raw.src_id, self.get_source_contents(raw.src_id));
+                    raw.src_id, self.get_source_contents(token.get_src_id()));
             }
         }
         if options.load_local_source_contents {
@@ -752,7 +752,7 @@ impl SourceMapIndex {
                                       token.get_src_col(),
                                       token.get_source(),
                                       token.get_name());
-                if !builder.has_source_contents(token.get_src_id()) {
+                if !builder.has_source_contents(raw.src_id) {
                     builder.set_source_contents(
                         raw.src_id, map.get_source_contents(token.get_src_id()));
                 }
